Install — django-vue-utilities 0.1 documentation

# Install

Install with the pip package manager.

    $ mkvirtualenv myvenv -p python3
    $ pip install django
    $ pip install django-vue-utils

After creating a project, add `django_vue_utilities` to `INSTALLED_APPS` in `settings.py`.

    INSTALLED_APPS = [
        # ...
        'django_vue_utilities',
    ]

Remember to update your `requirements.txt` file. In your project directory:

    $ pip freeze > requirements.txt